@@ -42,10 +42,8 @@ use Scalar::Util qw( blessed refaddr reftype weaken );
 use Carp qw( croak );
 
 use overload (
-    'eq' => sub { refaddr $_[0] eq refaddr $_[1] },
-    'ne' => sub { refaddr $_[0] ne refaddr $_[1] },
-    '==' => sub { refaddr $_[0] eq refaddr $_[1] },
-    '!=' => sub { refaddr $_[0] ne refaddr $_[1] },
+    'eq' => '_string_equals',
+    '==' => '_object_equals',
     '""' => sub { return shift->render },
     'bool'     => sub {1},
     'fallback' => 1,
@@ -111,7 +109,7 @@ __PACKAGE__->mk_inherited_merging_accessors(qw( tt_args config_callback ));
 *plugins           = \&plugin;
 *add_plugins       = \&add_plugin;
 
-our $VERSION = '0.07000';
+our $VERSION = '0.07002';
 $VERSION = eval $VERSION;
 
 Class::C3::initialize();
